@@ -9,7 +9,9 @@ PYPI = 'https://pypi.org/project/avispa-lattices'
 def github(library_object, property: Optional[str] = None):
 
     if property is not None:
-        library_object = getattr_static(library_object, property)._method
+        library_object = getattr_static(library_object, property)
+        if hasattr(library_object, '_method'):
+            library_object = library_object._method
 
     s = getsourcefile(library_object)
     if s is not None:
